@@ -198,11 +198,24 @@ class Recipe(zc.recipe.egg.Eggs):
         pkg_resources_stub.write("resource_filename = _dummy_func\n")
         pkg_resources_stub.close()
 
+    def write_pkg_resources(self, ws, d):
+        """Write original pkg_resources.py file from setuptools egg."""
+        setuptools_eggs = [e for e in ws.entries if 'setuptools' in e]
+        assert len(setuptools_eggs) == 1, "setuptools not found"
+        egg_contents = zipfile.ZipFile(setuptools_eggs[0])
+        pkg_resources = open(os.path.join(d, 'pkg_resources.py'), "w")
+        pkg_resources.write(egg_contents.read('pkg_resources.py'))
+        pkg_resources.close()
+
     def copy_packages(self, ws, lib):
         """Copy egg contents to lib-directory."""
         if not os.path.exists(lib):
             os.mkdir(lib)
-        self.write_pkg_resources_stub(lib)
+        if self.options.get(
+                'use_setuptools_pkg_resources', 'false').lower() == "true":
+            self.write_pkg_resources(ws, lib)
+        else:
+            self.write_pkg_resources_stub(lib)
         packages = self.options.get('packages', '').split()
         keys = [k.lower() for k in packages]
         for p in keys:
